package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaDocumentVerify;
import com.huiju.estateagents.service.ITaDocumentVerifyService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 资料审核  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-23
 */
@RestController
@RequestMapping("/")
public class TaDocumentVerifyController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaDocumentVerifyController.class);

    @Autowired
    public ITaDocumentVerifyService iTaDocumentVerifyService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/documentVerify",method= RequestMethod.GET)
    public ResponseBean documentVerifyList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaDocumentVerify> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaDocumentVerify> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaDocumentVerify> result = iTaDocumentVerifyService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("documentVerifyList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param documentVerify 实体对象
     * @return
     */
    @RequestMapping(value="/documentVerify",method= RequestMethod.POST)
    public ResponseBean documentVerifyAdd(@RequestBody TaDocumentVerify documentVerify){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaDocumentVerifyService.save(documentVerify)){
                responseBean.addSuccess(documentVerify);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("documentVerifyAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/documentVerify/{id}", method= RequestMethod.DELETE)
    public ResponseBean documentVerifyDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaDocumentVerifyService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("documentVerifyDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param documentVerify 实体对象
     * @return
     */
    @RequestMapping(value="/documentVerify/{id}",method= RequestMethod.PUT)
    public ResponseBean documentVerifyUpdate(@PathVariable Integer id,
                                        @RequestBody TaDocumentVerify documentVerify){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaDocumentVerifyService.updateById(documentVerify)){
                responseBean.addSuccess(documentVerify);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("documentVerifyUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/documentVerify/{id}",method= RequestMethod.GET)
    public ResponseBean documentVerifyGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaDocumentVerifyService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("documentVerifyDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
